#
# Recurse through filesystem applying user-defined processing to 
# any files therein. Items found are exported to processing scripts 
# as "$file". Processing scripts can then do things like:
# 
#   echo "`cat "$file" | sed s/foo/bar/g`" > "${file}"
#
# $1 - path to dir at which to begin recursion
# $2 - *ABSOLUTE* path of processing (bash) file 
# $3 - optional *ABSOLUTE* path to a text file with list of dirs to ignore
#
processFilesIn()
{
    local i
    local ignores_list
    local original_pwd="$PWD"
    local processing="$2"

    cd "$1"
    
    if [ ! -f "$processing" ]
    then
    	echo 'processing script ['${processing}'] not found from PWD ['${1}']'
        exit 1
    fi
    if [ -f "$3" ]
    then
        ignores_list=`cat "$3"`
    else
        ignores_list=""
    fi

    for i in *
    do
        if [ -d "$i" ]
        then
            if [ "$i" = "`echo $ignores_list | grep -o $i`" ]
            then
                echo "ignoring dir [$i]"
            else
                processFilesIn "$i" "$processing" "$3"
            fi            	
        else
            file=$i
            export file
            source $processing
        fi
    done
    cd $original_pwd
}

#
# Check if an item exists on a remote machine.
# Not tested with spaces in filenames.
#
# $1 - remote account of form: "foo@bar.com"
# $2 - path (root is remote account home dir)
# $3 - an item in the remote dir
#
remotePathExists()
{
    local dir_contents=`ssh "$1" ls "$2"`
    local target=`echo $dir_contents | grep "$3"`
    
    if [ "" != "$target" ]
    then
        echo 1
    else
        echo 0
    fi 
}
