#---------------------------------------------------------
#
# bash fns which may be useful in ebuild installer scripts
#
#---------------------------------------------------------

spartacus()
{
    if [ 'I am Spartacus!' = "`cat /root/.isdev`" ]
    then
        echo 'I am'
    fi
}

#
# Package installation from tarball.
#
# $1 - path to local overlay
#
checkLocalOverlay()
{
    local overlay=`echo "$1" | sed 's-/\$--g'`

    if [ ! -d "$1" ]
    then
        echo
        echo 'ERROR: portage overlay dir ['${1}'] does not appear to exist'
        echo 'exiting...'
        echo
        exit 1
    fi
    
    if [ "" = "`cat /etc/make.conf | grep $overlay | grep PORTDIR_OVERLAY`" ]
    then
        echo
        echo 'WARNING: ['${overlay}'] is not a portage overlay'
        echo 'Please add this line to /etc/make.conf:'
        echo
        echo 'PORTDIR_OVERLAY="'${overlay}'"'
        echo
        exit 1
    fi
}

#
# Package installation from tarball.
#
# When installing from a tarball rather than with rsync, it can be convenient
# to rm -rv all the existing files in the package dir. However, an error in 
# $package_dir can have unpleasant repercussions... This fn checks for a null
# value which, if present, would result in deletion of the entire local overlay.
# Oops.
#
# $1 - path of local overlay
# $2 - package name eg app-admin/gem, media-sound/ardour etc
#
badPackageDir()
{
    if [ ${1}${2} = ${1} ]
    then
    	echo
        echo 'developer error: the package path evaluates to ['${1}']'
        echo 'this is the same as the overlay path ['${1}']'
        echo 'better not rm -rv your local overlay huh?'
        echo 'exiting now...'
        echo
        exit 1
    fi
}
#
# Package installation from tarball.
#
# Clear out the old files.
#
# $1 - package path eg /usr/local/portage/app-admin/gem
#
rmOldFiles()
{
    local previous=$PWD

    # check if previously installed (may not be)
    if [ -d ${1} ]
    then
        cd ${1}
        echo "out with the old..."
        rm -rv ./*
        echo "and in with the new..."
    fi
    cd $previous
}
