#
# Create an rsync exclude clause from a list of items.
# $1 - string, space-separated items !!remember to double-quote arg $1
#
getExcludeClause()
{
    local clause=' '
    local list=$1
    for item in ${list[@]}
    do
        clause=${clause}' --exclude="'${item}'"'
    done
    echo $clause
    return 0
}
#
# NOTE: will only work with a policy based on $common_short_options 
# NOTE: you *MUST* quote the input args to preserve leading spaces!
#
addOption() # $option  "$rsync_clause"
{
    local tmp
    
    tmp=`echo "$2" | sed "s/\($common_short_options\)/\1$1/"`
    echo "$tmp"
    return 0
}
#
# add n to the list of short options
# NOTE: you *MUST* quote the input args!
#
makePretend()
{
    echo ' '`echo "$1" | sed 's/^\s*-/ -n/g'` 
}
#
# Dir contains some items which should be copied with a different rsync policy
# (and all non-default items should use the same policy).
#
syncWithExceptions()
{
    local default_policy="$1"
    local other_policy="$2"
    local subset="$3"
    local src="$4"
    local dest="$5"
    local item=''
    
    default_policy=${default_policy}' '`getExcludeClause "$subset"`
    eval rsync "$default_policy" "$src" "$dest"

    for item in ${subset[@]}
    do
        eval rsync "$other_policy" "${src}${item}" "${dest}${item}"
    done
    
}

checkClockSync()
{
    rdate=`ssh $1 date`
    ldate=`date`
    
    if [ "$rdate" = "$ldate" ]
    then
        echo "0"
        return 0
    else
        echo "local [$ldate] is not in sync with $1 [$rdate]"
        return 1
    fi
}

